@@ -6,10 +6,10 @@ use autodie ':all';
 use namespace::autoclean;
 
 use Readonly;
-use Moo::Lax; use MooX::StrictConstructor;
+use Moo; use MooX::StrictConstructor;
 use CloudFlare::Client::Types 'ErrorCode';
 
-our $VERSION = '0.03_5'; # TRIAL VERSION
+our $VERSION = '0.03_6'; # TRIAL VERSION
 
 extends 'Throwable::Error';
 
@@ -31,7 +31,7 @@ CloudFlare::Client::Exception::Upstream - Upstream CloudFlare API Exception
 
 =head1 VERSION
 
-version 0.03_5
+version 0.03_6
 
 =head1 SYNOPSIS
 
